#!/bin/bash

die() {
  echo $0: "$@" >&2
  usage 
  exit 1
}

usage() {
  cat <<END >&2
USAGE
  ebr-ltl-synth [-smv | -tlsf] -b [demiurge | safetysynth] [-s] <file>

OPTIONS
  -smv    The input file is in SMV format
  -tlsf   The input file is in TLSF format
  -b      The backend used for solving safety games 
          ('demiurge' or 'safetysynth')
  -s      Synthesize a strategy if the specification is realizable
END
  exit 1
}

format=
if [ "$1" = "-h" ] || [ "$1" == "--help" ]; then
  die ""
elif [ "$1" = "-smv" ]; then
  format="-smv"
  shift
elif [ "$1" = "-tlsf" ]; then
  format="-tlsf"
  shift
else
  die "Unknown format."
fi

backend=
shift
if [ "$1" = "demiurge" ]; then
  backend="demiurge" 
  shift
elif [ "$1" = "safetysynth" ]; then
  backend="safetysynth"
  shift
else
  die "Unknown backend."
fi

synth=
if [ "$1" = "-s" ]; then
  synth=-s
  shift
fi

[ -z "$1" ] && usage
[ -f "$1" ] || die "Unable to open '$1': No such file or directory"
[ -r "$1" ] || die "Unable to open '$1': Permission denied"

docker --version > /dev/null || die "Unable to find \`docker'"

docker run --rm -it -v $(pwd):$(pwd) -w $(pwd) \
  lucageatti/ebr-ltl-synth-no-static:latest $1 $format -b $backend $synth 
